︠33a4ce85-88d9-4c8f-a241-e788b2018729︠
complex_plot?
︡2813370e-902b-4ca8-9571-1c1b4505b166︡{"code":{"source":"File: /usr/local/sage/sage-6.5/src/sage/plot/complex_plot.pyx\nSignature : complex_plot(f, xrange, yrange, plot_points=100, interpolation='catrom', **kwds)\nDocstring :\n\"complex_plot\" takes a complex function of one variable, f(z) and\nplots output of the function over the specified \"xrange\" and\n\"yrange\" as demonstrated below. The magnitude of the output is\nindicated by the brightness (with zero being black and infinity\nbeing white) while the argument is represented by the hue (with red\nbeing positive real, and increasing through orange, yellow, ... as\nthe argument increases).\n\n\"complex_plot(f, (xmin, xmax), (ymin, ymax), ...)\"\n\nINPUT:\n\n* \"f\" -- a function of a single complex value x + iy\n\n* \"(xmin, xmax)\" -- 2-tuple, the range of \"x\" values\n\n* \"(ymin, ymax)\" -- 2-tuple, the range of \"y\" values\n\nThe following inputs must all be passed in as named parameters:\n\n* \"plot_points\" -- integer (default: 100); number of points to\n  plot in each direction of the grid\n\n* \"interpolation\" -- string (default: \"'catrom'\"), the\n  interpolation method to use: \"'bilinear'\", \"'bicubic'\",\n  \"'spline16'\", \"'spline36'\", \"'quadric'\", \"'gaussian'\", \"'sinc'\",\n  \"'bessel'\", \"'mitchell'\", \"'lanczos'\", \"'catrom'\", \"'hermite'\",\n  \"'hanning'\", \"'hamming'\", \"'kaiser'\"\n\nEXAMPLES:\n\nHere we plot a couple of simple functions:\n\n   sage: complex_plot(sqrt(x), (-5, 5), (-5, 5))\n   Graphics object consisting of 1 graphics primitive\n\n   sage: complex_plot(sin(x), (-5, 5), (-5, 5))\n   Graphics object consisting of 1 graphics primitive\n\n   sage: complex_plot(log(x), (-10, 10), (-10, 10))\n   Graphics object consisting of 1 graphics primitive\n\n   sage: complex_plot(exp(x), (-10, 10), (-10, 10))\n   Graphics object consisting of 1 graphics primitive\n\nA function with some nice zeros and a pole:\n\n   sage: f(z) = z^5 + z - 1 + 1/z\n   sage: complex_plot(f, (-3, 3), (-3, 3))\n   Graphics object consisting of 1 graphics primitive\n\nHere is the identity, useful for seeing what values map to what\ncolors:\n\n   sage: complex_plot(lambda z: z, (-3, 3), (-3, 3))\n   Graphics object consisting of 1 graphics primitive\n\nThe Riemann Zeta function:\n\n   sage: complex_plot(zeta, (-30,30), (-30,30))\n   Graphics object consisting of 1 graphics primitive\n\nExtra options will get passed on to show(), as long as they are\nvalid:\n\n   sage: complex_plot(lambda z: z, (-3, 3), (-3, 3), figsize=[1,1])\n   Graphics object consisting of 1 graphics primitive\n\n   sage: complex_plot(lambda z: z, (-3, 3), (-3, 3)).show(figsize=[1,1]) # These are equivalent\n\nTESTS:\n\nTest to make sure that using fast_callable functions works:\n\n   sage: f(x) = x^2\n   sage: g = fast_callable(f, domain=CC, vars='x')\n   sage: h = fast_callable(f, domain=CDF, vars='x')\n   sage: P = complex_plot(f, (-10, 10), (-10, 10))\n   sage: Q = complex_plot(g, (-10, 10), (-10, 10))\n   sage: R = complex_plot(h, (-10, 10), (-10, 10))\n   sage: S = complex_plot(exp(x)-sin(x), (-10, 10), (-10, 10))\n   sage: P; Q; R; S\n   Graphics object consisting of 1 graphics primitive\n   Graphics object consisting of 1 graphics primitive\n   Graphics object consisting of 1 graphics primitive\n   Graphics object consisting of 1 graphics primitive\n\nTest to make sure symbolic functions still work without declaring a\nvariable.  (We don't do this in practice because it doesn't use\nfast_callable, so it is much slower.)\n\n   sage: complex_plot(sqrt, (-5, 5), (-5, 5))\n   Graphics object consisting of 1 graphics primitive","mode":"text/x-rst","lineno":-1,"filename":null}}︡
︠66ab1df0-3d94-4922-aef8-7d3c5eb39d27︠
%md

Could William modify the plot to have different colors other than the bold red and make the other half less faded? The Cornell image is similar looking to yours but with a grey background (which is a bit dull), but the colors in the other half are brighter. Also the cover image file resolution needs to be 300 dpi at size.
︠bd641047-cf51-48b3-895c-ba83436a432b︠
300*8
︡a8c0de21-df65-47df-836b-644ff5028665︡{"stdout":"2400\n"}︡
︠49781313-ba5b-48b6-8303-6b359adc51a3︠
%time
B = 50
show(complex_plot(zeta, (-B,B),(-B,B),
             frame=False, axes=False,
             plot_points=400), svg=False, figsize=[8,8])
︡ab39ab4d-de78-4925-a0d0-f227764f374f︡{"once":false,"file":{"show":true,"uuid":"6f511b0c-b594-478c-8b45-ce8fb9284e52","filename":"/projects/54949eee-57da-4bd7-bb43-c2602b429f9a/.sage/temp/compute7dc2/21121/tmp_xJuJcg.png"}}︡{"html":"<div align='center'></div>"}︡{"stdout":"CPU time: 29.53 s, Wall time: 32.14 s"}︡{"stdout":"\n"}︡
︠123bbb34-1806-45cc-91dc-31be9f4fd937︠
%time
B = 50
save(complex_plot(zeta, (-B,B),(-B,B),
             frame=False, axes=False,
             plot_points=2400), 'zeta2400.png', figsize=[8,8])
︡1186e65c-8db8-4495-a878-af0a5b8e7028︡{"stdout":"CPU time: 1692.61 s, Wall time: 1697.98 s"}︡{"stdout":"\n"}︡
︠a3adb394-9b2b-4b98-abaf-0bb05eec15c6︠
1692.61/60.0
︡7026f1dd-536e-4259-b3d2-623b0912d3e4︡{"stdout":"28.2101666666667\n"}︡
︠1ce4ee36-4774-4453-a926-9fac4711c4fd︠




























i = CDF(I)
def f(z):
    return zeta(z)*i
complex_plot(f, (-50,50),(-50,50),
             frame=False, axes=False, aspect_ratio=1)
︡7e8e9834-e5a4-4c99-b942-5005968c733c︡{"once":false,"file":{"show":true,"uuid":"cf3924ed-26e0-430e-b86c-158186234cb2","filename":"/projects/54949eee-57da-4bd7-bb43-c2602b429f9a/.sage/temp/compute7dc2/21121/tmp_ycZPWc.svg"}}︡{"html":"<div align='center'></div>"}︡
︠67673f0a-52e1-4cb3-b84c-9c5d606bd2f1︠
def f(z):
    return zeta(z)*(-1)
complex_plot(f, (-50,50),(-50,50),
             frame=False, axes=False, aspect_ratio=1)

︡5e2cca0e-2c89-48ca-951a-8b1f28e6cb6e︡{"once":false,"file":{"show":true,"uuid":"2d0d64d8-3d42-49b2-bb11-318a6714be04","filename":"/projects/54949eee-57da-4bd7-bb43-c2602b429f9a/.sage/temp/compute7dc2/21121/tmp_cJ3HKT.svg"}}︡{"html":"<div align='center'></div>"}︡
︠76ed1b27-0411-424d-b1eb-68160766bc3d︠



































